@@ -54,9 +54,14 @@ Sample usage:
 """
 
 __author__ = "Gilad Raphaelli"
-__version__ = "0.4.1"
+__version__ = "0.4.2"
 
-import md5,mimetypes,urllib,urllib2
+try:
+	import hashlib
+except ImportError:
+	import md5 as hashlib
+
+import mimetypes,urllib,urllib2
 import warnings
 import API
 
@@ -106,7 +111,7 @@ def sign_args(secret, args):
 		if args[key] is not None:
 			sig += str(args[key])
 
-	return md5.new(sig).hexdigest()
+	return hashlib.md5(sig).hexdigest()
 	
 class APIError(Exception): pass
 class APIWarning(RuntimeWarning): pass
